@@ -6,6 +6,11 @@
 #' @param yaxis_thresh Value used for specifying y-axis max limit
 #' @param xlabel Used to overwrite default x-axis label
 #' @param ylabel Used to overwrite default y-axis label
+#' @param plot_title A plot title used to title the ggplot. If left as the
+#'   default (FALSE), the plot will be titled using the name of the HUC from
+#'   nhdPlus
+#' @param break_var The name of the variable in watershed.df to be filtered for
+#'   by the breakpt, defaults to the expected name "x_var"
 #' @return Object containing plot image and dataframe of ELF statistics
 #' @import ggplot2
 #' @import quantreg
@@ -15,7 +20,8 @@
 #' \donttest{
 #' # We don't run this example by R CMD check, because it takes >10s
 #'
-#' watershed.df <- elfdata(watershed.code = '0208020104', ichthy.localpath = tempdir())
+#' watershed.df <- elfdata(watershed.code = '0208020104',
+#'  ichthy.localpath = tempdir(), use_cache = FALSE)
 #' breakpt <- 500
 #' elfgen(
 #'    "watershed.df" = watershed.df,
@@ -25,7 +31,16 @@
 #'    "ylabel" = "Fish Species Richness"
 #'    )
 #' }
-elfgen <- function(watershed.df,quantile,breakpt,yaxis_thresh,xlabel = FALSE,ylabel = FALSE) {
+elfgen <- function(
+    watershed.df,
+    quantile,
+    breakpt,
+    yaxis_thresh,
+    xlabel = FALSE,
+    ylabel = FALSE,
+    plot_title = FALSE,
+    break_var = "x_var"
+  ) {
 
    # DEFAULT breakpt IF NONE SUPPLIED
    if(missing(breakpt)) {
@@ -40,7 +55,7 @@ elfgen <- function(watershed.df,quantile,breakpt,yaxis_thresh,xlabel = FALSE,yla
    colnames(watershed.df)[3] <- "watershed"
 
    full_dataset <- watershed.df
-   data <- watershed.df[!(watershed.df$x_var > breakpt),]
+   data <- watershed.df[!(watershed.df[,break_var] > breakpt),]
 
    #Prevents: Error in rq.fit.br(x, y, tau = tau, ...) : Singular design matrix (and others)
    if(length(data[,1]) <= 2) {
@@ -94,7 +109,11 @@ elfgen <- function(watershed.df,quantile,breakpt,yaxis_thresh,xlabel = FALSE,yla
    }
 
    #Plot titles
-   plot_title <- paste("Watershed: ",watershed.df$watershed[1],"\n",sep="");
+   if (is.logical(plot_title)) {
+     # Guess as outlet
+     outlet = watershed.df[watershed.df[,1] == max(watershed.df[,1]),][1,]
+     plot_title = paste("Watershed: ",as.character(outlet[3]),"\n",sep="")
+   }
    flow_title <- colnames(watershed.df.raw[1])
    biometric_title <- colnames(watershed.df.raw[2])
    if (xlabel != FALSE) {flow_title <- xlabel}
